@@ -1,7 +1,7 @@
 package App::ListOrgHeadlines;
 
-our $DATE = '2016-03-24'; # DATE
-our $VERSION = '0.40'; # VERSION
+our $DATE = '2016-04-01'; # DATE
+our $VERSION = '0.41'; # VERSION
 
 use 5.010001;
 use strict;
@@ -325,8 +325,8 @@ sub list_org_headlines {
 
     my @res;
 
-    my %docs = App::OrgUtils::_load_org_files_with_cache(
-        $files, $args{cache_dir}, {time_zone=>$tz});
+    my %docs = App::OrgUtils::_load_org_files(
+        $files, {time_zone=>$tz});
     for my $file (keys %docs) {
         my $doc = $docs{$file};
         $doc->walk(
@@ -398,7 +398,7 @@ App::ListOrgHeadlines - List all headlines in all Org files
 
 =head1 VERSION
 
-This document describes version 0.40 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2016-03-24.
+This document describes version 0.41 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2016-04-01.
 
 =head1 SYNOPSIS
 
@@ -419,13 +419,6 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<cache_dir> => I<str>
-
-Cache Org parse result.
-
-Since Org::Parser can spend some time to parse largish Org files, this is an
-option to store the parse result. Caching is turned on if this argument is set.
-
 =item * B<detail> => I<bool> (default: 0)
 
 Show details instead of just titles.
