@@ -1,7 +1,7 @@
 package App::OrgUtils;
 
-our $DATE = '2016-03-24'; # DATE
-our $VERSION = '0.40'; # VERSION
+our $DATE = '2016-04-01'; # DATE
+our $VERSION = '0.41'; # VERSION
 
 use 5.010;
 use strict;
@@ -19,17 +19,6 @@ our %common_args1 = (
         'x.schema.element_entity' => 'filename',
         'x.name.is_plural' => 1,
     },
-    cache_dir => {
-        schema => ['str*'],
-        summary => 'Cache Org parse result',
-        description => <<'_',
-
-Since Org::Parser can spend some time to parse largish Org files, this is an
-option to store the parse result. Caching is turned on if this argument is set.
-
-_
-        'x.schema.entity' => 'dirname',
-    },
     time_zone => {
         schema => ['str'],
         summary => 'Will be passed to parser\'s options',
@@ -61,8 +50,8 @@ our $_complete_state = sub {
     # read org
     return unless $args->{files} && @{ $args->{files} };
     my $tz = $args->{time_zone} // $ENV{TZ} // "UTC";
-    my %docs = App::OrgUtils::_load_org_files_with_cache(
-        [grep {-f} @{ $args->{files} }], $args->{cache_dir}, {time_zone=>$tz});
+    my %docs = App::OrgUtils::_load_org_files(
+        [grep {-f} @{ $args->{files} }], {time_zone=>$tz});
 
     # get todo states
     my @states;
@@ -93,8 +82,8 @@ our $_complete_priority = sub {
     # read org
     return unless $args->{files} && @{ $args->{files} };
     my $tz = $args->{time_zone} // $ENV{TZ} // "UTC";
-    my %docs = App::OrgUtils::_load_org_files_with_cache(
-        [grep {-f} @{ $args->{files} }], $args->{cache_dir}, {time_zone=>$tz});
+    my %docs = App::OrgUtils::_load_org_files(
+        [grep {-f} @{ $args->{files} }], {time_zone=>$tz});
 
     # get priorities
     my @prios;
@@ -125,8 +114,8 @@ our $_complete_tags = sub {
     # read org
     return unless $args->{files} && @{ $args->{files} };
     my $tz = $args->{time_zone} // $ENV{TZ} // "UTC";
-    my %docs = App::OrgUtils::_load_org_files_with_cache(
-        [grep {-f} @{ $args->{files} }], $args->{cache_dir}, {time_zone=>$tz});
+    my %docs = App::OrgUtils::_load_org_files(
+        [grep {-f} @{ $args->{files} }], {time_zone=>$tz});
 
     # collect tags
     my @tags;
@@ -144,29 +133,20 @@ our $_complete_tags = sub {
     Complete::Util::complete_array_elem(array=>\@tags, word=>$args{word});
 };
 
-sub _load_org_files_with_cache {
+sub _load_org_files {
     require Cwd;
     require Digest::MD5;
 
-    my ($files, $cache_dir, $opts0) = @_;
+    my ($files, $opts0) = @_;
     $files or die "Please specify files";
 
     my $orgp = Org::Parser->new;
     my %docs;
     for my $file (@$files) {
-        my $cf;
-        if ($cache_dir) {
-            my $afile = Cwd::abs_path($file) or die "Can't find $file";
-            my $afilel = $afile; $afilel =~ s!.+/!!;
-            $cf = "$cache_dir/$afilel.".Digest::MD5::md5_hex($afile).
-                ".storable";
-            $log->debug("Parsing file $file (cache file $cf) ...");
-        } else {
-            $log->debug("Parsing file $file ...");
-        }
-
         my $opts = { %{$opts0 // {}} };
-        $opts->{cache_file} = $cf if $cf;
+        # by default turn on cache, unless user specifically has
+        # PERL_ORG_PARSER_CACHE set to 0.
+        $opts->{cache} = 1 if $ENV{PERL_ORG_PARSER_CACHE} // 1;
         $docs{$file} = $orgp->parse_file($file, $opts);
     }
 
@@ -188,7 +168,7 @@ App::OrgUtils - Some utilities for Org documents
 
 =head1 VERSION
 
-This document describes version 0.40 of App::OrgUtils (from Perl distribution App-OrgUtils), released on 2016-03-24.
+This document describes version 0.41 of App::OrgUtils (from Perl distribution App-OrgUtils), released on 2016-04-01.
 
 =head1 DESCRIPTION
 
@@ -218,8 +198,6 @@ following are the included scripts:
 
 =item * L<list-org-todos>
 
-=item * L<select-org-elements>
-
 =item * L<stat-org-document>
 
 =back
